use crate::{config::SSHConfig, pkg::install_pkgs};
use std::io::Write;

pub fn setup_ssh(conf: &Option<SSHConfig>) {
    if let Some(conf) = conf {
        install_pkgs(&["openssh"]);

        if let Some(sshd_config) = &conf.sshd_config {
            let content = std::fs::read_to_string(sshd_config).unwrap();
            std::fs::write("/mnt/etc/ssh/sshd_config", content).unwrap();
        }

        for key in &conf.key {
            for user in &key.users {
                let path = if user == "root" {
                    std::fs::create_dir_all("/root/.ssh").unwrap();
                    "/root/.ssh/authorized_keys".to_string()
                } else {
                    std::fs::create_dir_all(&format!("/home/{user}/.ssh")).unwrap();
                    format!("/home/{user}/.ssh/authorized_keys")
                };

                let mut authorized_keys = std::fs::OpenOptions::new()
                    .append(true)
                    .create(true)
                    .open(path)
                    .unwrap();

                writeln!(authorized_keys, "{}", format!("{}\n", key.key)).unwrap();
            }
        }
    }
}
